from lumaCLI import app
from typer.testing import CliRunner
from lumaCLI.tests.utils import TESTS_DIR, DUMMY_ENDPOINT


runner = CliRunner()


def test_ingest():
    result = runner.invoke(
        app,
        [
            "dbt",
            "ingest",
            TESTS_DIR,
            "--endpoint",
            DUMMY_ENDPOINT,
        ],
    )
    assert result.exit_code == 0, result.output



#!/usr/bin/env python

import typer
import lumaCLI.dbt as dbt
import urllib3

urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)


app = typer.Typer()

app.add_typer(dbt.app, name="dbt")


def cli():
    """For python script installation purposes (flit)"""
    app()


if __name__ == "__main__":
    app()



from lumaCLI.tests.utils import MANIFEST_JSON
from lumaCLI.common import validate_json, json_to_dict


def test_validate_json():
    is_json = validate_json(json_path=MANIFEST_JSON)
    assert is_json


def test_validate_json_to_dict():
    dict_data = json_to_dict(json_path=MANIFEST_JSON)
    assert isinstance(dict_data, dict)
